package fr.univlyon1.mif18;

import org.apache.jena.graph.Graph;
import org.apache.jena.query.*;
import org.apache.jena.rdf.model.Model;
import org.apache.jena.rdf.model.ModelFactory;
import org.apache.jena.riot.RDFDataMgr;
import org.junit.Test;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.net.URL;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;

public class SPARQLTest {

    private static final URL EXEMPLE_GRAPH_URI = SPARQLTest.class.getResource("/example.ttl");

    // Logger pour afficher des messages
    private static final Logger LOG = LoggerFactory.getLogger(SPARQLTest.class);

    @Test
    public void runQueryOnGraph() {
        // Un graphe exemple lu dans un fichier
        // Dans l'implémentation ce graphe devra être remplacé par votre implémentation de l'interface Jena Graph
        Graph exemple = RDFDataMgr.loadGraph(EXEMPLE_GRAPH_URI.toExternalForm());
        // Exemple inspiré de la documentation Jena:
        // https://jena.apache.org/documentation/query/app_api.html
        Model model = ModelFactory.createModelForGraph(exemple);
        String sparqlQueryString = "SELECT ?p ?o WHERE { <http://www.recettes.com/Instruction/id/gateau/3> ?p ?o. }";
        Query sparqlQuery = QueryFactory.create(sparqlQueryString);
        QueryExecution exec = QueryExecutionFactory.create(sparqlQuery,model);
        ResultSet rs = exec.execSelect();
        int count = 0;
        while(rs.hasNext()) {
            QuerySolution solution = rs.nextSolution();
            LOG.info("found value for ?p: {}",solution.get("p"));
            LOG.info("found value for ?o: {}",solution.get("o"));
            count ++;
        }
        exec.close();
        assertEquals(3,count);
    }

}
